
XEP-0382: Spoiler Messages
==========================

.. module:: slixmpp.plugins.xep_0382

.. autoclass:: XEP_0382
    :members:
    :exclude-members: session_bind, plugin_init, plugin_end


Stanza elements
---------------

.. automodule:: slixmpp.plugins.xep_0382.stanza
    :members:
    :undoc-members:

